@@ -60,7 +60,7 @@ class MongodbId(BaseModel):
 class ChainRef(BaseModel):
     "Some POST messages have a 'ref' field referencing other content"
     chain: Chain
-    channel: Optional[str]
+    channel: Optional[str] = None
     item_content: str
     item_hash: str
     item_type: ItemType
@@ -98,11 +98,12 @@ class AggregateContentKey(BaseModel):
 class PostContent(BaseContent):
     "Content of a POST message"
     content: Optional[Any] = Field(
+        default=None,
         description="User-generated content of a POST message"
     )
     ref: Optional[Union[str, ChainRef]] = Field(
-        description="Other message referenced by this one",
         default=None,
+        description="Other message referenced by this one",
     )
     type: str = Field(description="User-generated 'content-type' of a POST message")
 
@@ -135,9 +136,9 @@ class StoreContent(BaseContent):
     "Content of a STORE message"
     item_type: ItemType
     item_hash: str
-    size: Optional[int]  # Generated by the node on storage
-    content_type: Optional[str]  # Generated by the node on storage
-    ref: Optional[str]
+    size: Optional[int] = None  # Generated by the node on storage
+    content_type: Optional[str] = None  # Generated by the node on storage
+    ref: Optional[str] = None
 
     class Config:
         extra = Extra.allow
@@ -146,7 +147,7 @@ class StoreContent(BaseContent):
 class ForgetContent(BaseContent):
     "Content of a FORGET message"
     hashes: List[str]
-    reason: Optional[str]
+    reason: Optional[str] = None
 
     def __hash__(self):
         # Convert List to Tuple for hashing
@@ -157,32 +158,38 @@ class ForgetContent(BaseContent):
 
 class BaseMessage(BaseModel):
     "Base template for all messages"
-    id_: Optional[MongodbId] = Field(alias="_id", description="MongoDB metadata")
+    id_: Optional[MongodbId] = Field(alias="_id", default=None, description="MongoDB metadata")
     chain: Chain = Field(description="Blockchain used for this message")
 
     sender: str = Field(description="Address of the sender")
     type: MessageType = Field(description="Type of message (POST, AGGREGATE or STORE)")
     channel: Optional[str] = Field(
+        default=None,
         description="Channel of the message, one application ideally has one channel"
     )
     confirmations: Optional[List[MessageConfirmation]] = Field(
+        default=None,
         description="Blockchain confirmations of the message"
     )
     confirmed: Optional[bool] = Field(
+        default=None,
         description="Indicates that the message has been confirmed on a blockchain"
     )
     signature: str = Field(
         description="Cryptographic signature of the message by the sender"
     )
     size: Optional[int] = Field(
+        default=None,
         description="Size of the content"
     )  # Almost always present
     time: float = Field(description="Unix timestamp when the message was published")
     item_type: ItemType = Field(description="Storage method used for the content")
     item_content: Optional[str] = Field(
+        default=None,
         description="JSON serialization of the message when 'item_type' is 'inline'"
     )
     hash_type: Optional[HashType] = Field(
+        default=None,
         description="Hashing algorithm used to compute 'item_hash'"
     )
     item_hash: str = Field(description="Hash of the content (sha256 by default)")
